#!/bin/sh

WELCOME="Welcome to the XIV Host Attachment Bundle installer."
CONFIRM_INSTALL_PROMPT="Would you like to proceed and install the Host Attachment Kit?"
ALREADY_INSTALLED="NOTICE: Another version of Host Attachment Kit is already installed. The installer will replace the currently installed version."
SEEKING_INSTALLED_VERSIONS="Please wait while the installer validates your existing configuration..."
CONFIRM_UPDATE_PROMPT="Would you like to replace the installed Host Attachment Kit?"
USER_ABORT="The installation was canceled."
ENTER_TO_PROCEED="Press [Enter] to proceed"
INSTALLING="Please wait, the Host Attachment Bundle is being installed..."
ERROR="Installation FAILED. Please refer to install.log for more information."
SUCCESS="Installation successful."
WHATS_NEXT="Please refer to the Host Attachment Guide for information on how to configure this host."
SEPARATOR="---------------------------------------------------------------"


echo $WELCOME 1>&2
while [ 1 ]; do
  echo "$CONFIRM_INSTALL_PROMPT [Y/n]:" 1>&2
  read ans
  if [ "$ans" = "yes" ] || [ "$ans" = "y" ] || [ -z "$ans" ]; then
    break
  fi
  echo $SEPARATOR 1>&2
  if [ "$ans" = "no" ] || [ "$ans" = "n" ]; then
    echo $USER_ABORT 1>&2
    echo 1>&2
    exit 1
  fi
  echo "Invalid input ($ans); Valid replies are 'y' or 'yes' to confirm and 'n' or 'no' to abort."
done

INSTALLER_DIR=`dirname $0`
cd $INSTALLER_DIR
OSNAME=`uname -s | tr -s '[:upper:]' '[:lower:]'`
CUR_DIR=`pwd`
INST_SCRIPT=$CUR_DIR/scripts/pkginst.$OSNAME.sh
PRE_SCRIPT=$CUR_DIR/scripts/preinst.$OSNAME.sh
POST_SCRIPT=$CUR_DIR/scripts/postinst.$OSNAME.sh
XPYV_UPDATE=$CUR_DIR/scripts/xpyv_upgrade.py
IS_INSTALLED_SCRIPT=$CUR_DIR/scripts/is_installed.$OSNAME.sh
MOTD_TXT=$CUR_DIR/scripts/motd.$OSNAME.txt
LOG=$CUR_DIR/install.log

echo $SEEKING_INSTALLED_VERSIONS 1>&2
if [ -x "$IS_INSTALLED_SCRIPT" ] && $IS_INSTALLED_SCRIPT > /dev/null 2>&1; then
  echo $SEPARATOR 1>&2
  echo "$ALREADY_INSTALLED" 1>&2
  while [ 1 ]; do
    echo "$CONFIRM_UPDATE_PROMPT [Y/n]:" 1>&2
    read ans
    if [ "$ans" = "yes" ] || [ "$ans" = "y" ] || [ -z "$ans" ]; then
      break
    fi
    echo $SEPARATOR 1>&2
    if [ "$ans" = "no" ] || [ "$ans" = "n" ]; then
      echo $USER_ABORT 1>&2
      echo 1>&2
      exit 1
    fi
    echo "Invalid input ($ans); Valid replies are 'y' or 'yes' to confirm and 'n' or 'no' to abort."
  done
fi

echo $SEPARATOR 1>&2
echo >> $LOG
echo "Installer: `date`: Installation started" >> $LOG
echo $INSTALLING 1>&2

if [ -r "$MOTD_TXT" ]; then
    echo "Displaying message in '$MOTD_TXT'" >> $LOG
    cat $MOTD_TXT
fi

if [ -x "$PRE_SCRIPT" ]; then
	echo "Installer: running pre-install script '$PRE_SCRIPT'" >> $LOG
	$PRE_SCRIPT >> $LOG 2>&1 || exit $?
else
	echo "Installer: there is no pre-install script for this platform ($OSNAME)" >> $LOG
fi

echo "Installer: Installation script is '$INST_SCRIPT'" >> $LOG

for pkgname in `cat packages/pkg.list`; do
  if echo "$pkgname" | grep "xpyv-" > /dev/null; then
    echo "Installer: Checking if xpyv needs an update..." >> $LOG
    if xpyv "$XPYV_UPDATE" "$pkgname" > /dev/null 2>&1; then
      echo "Installer: No need to update xpyv" >> $LOG
      continue
    else
      echo "Installer: running install script for '$pkgname'..." >> $LOG
      $INST_SCRIPT "$CUR_DIR/packages/$pkgname" >> $LOG 2>&1
      RET=$?
    fi
  else
    echo "Installer: running install script for '$pkgname'..." >> $LOG
    $INST_SCRIPT "$CUR_DIR/packages/$pkgname" >> $LOG 2>&1
    RET=$?
  fi
  # Check for error
  if [ "$RET" != "0" ]; then
    echo "Installer: Install-Script '$INST_SCRIPT' for package '$pkgname' failed." >> $LOG
    echo $ERROR 1>&2
    exit 1
  fi
done

if [ -x "$POST_SCRIPT" ]; then
	echo "Installer: running post-install script '$POST_SCRIPT'" >> $LOG
	$POST_SCRIPT >> $LOG 2>&1
    if [ "$?" != "0" ]; then
      echo "Installer: Post-Scipt '$POST_SCRIPT' failed." >> $LOG
      echo $ERROR 1>&2
      exit 1
    fi
else
	echo "Installer: there is no post-install script for this platform ($OSNAME)" >> $LOG
fi

echo "Installer: $SUCCESS" >> $LOG
echo $SEPARATOR 1>&2
echo $SUCCESS 1>&2
echo $WHATS_NEXT 1>&2
echo 1>&2
exit 0
