#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging
import os

from hostattachment.exceptions import HostAttachmentError

def detect_iscsi_method(backup_path):
    """Decides if it's OpenIscsi (modern) or LinuxIscsi (deprecated), and
    returns the right object"""
    if os.path.exists("/sbin/iscsiadm"):
        logging.debug("OpenIscsi detected")
        from open_iscsi import OpenIscsi
        return OpenIscsi(backup_path)
    elif os.path.exists("/sbin/iscsi-device"):
        logging.debug("LinuxIscsi detected")
        from linux_iscsi import LinuxIscsi
        return LinuxIscsi(backup_path)
    else:
        raise HostAttachmentError("No iSCSI component was detected")
