#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging

from hostattachment.iscsicommon import test_iscsi_connectivity
from hostattachment.exceptions import HostAttachmentError
from execute import ExternalCommand
from nextra import Nextra

class ConnectionManager(object):
    def __init__(self, backup_path):
#        self.log_used_classes()
        pass

    def log_used_classes(self):
        self.logger.log_a_class(Nextra)

    def connect(self, ip_address):
        test_iscsi_connectivity(ip_address)
            
        nextra = Nextra(ip_address)
        if not nextra.query():
            logging.error('Failed to query XIV array on IP Address %s' % ip_address)
            return False
        nextra.discover_from_all_portals()
        nextra.connect_to_all_portals()
        return True
        
    def disconnect(self, ip_address):
        nextra = Nextra(ip_address)
        try:
            test_iscsi_connectivity(ip_address)
        except HostAttachmentError, e:
            # Special case: we have no connectivity but we want to remove
            logging.warning("Couldn't query portal, removing only " + \
                "%s, instead of all related IPs" % (ip_address))
            nextra.disconnect_from_portal(ip_address)
            nextra.undiscover_through_portal(ip_address)

        else:
            # Regular case, get all IPs by querying the portal
            nextra.query()
            nextra.disconnect_from_all_portals()
            nextra.undiscover_from_all_portals()

    def is_configured(self):
        return True

    def print_all(self):
        self.print_discoveries()
        self.print_nodes()
        self.print_sessions()
        print ''

    def print_discoveries(self):
        print 'Discovered portals and targets:'
        discovery = ExternalCommand('iscsiadm -m discovery')
        discovery.execute()
        discovery.print_output()
        print ''

    def print_nodes(self):
        print 'Discovered portals and targets:'
        nodes = ExternalCommand('iscsiadm -m node')
        nodes.execute()
        nodes.print_output()
        print ''

    def print_sessions(self):
        print 'Current connected portals and targets:'
        sessions = ExternalCommand('iscsiadm -m session')
        sessions.execute()
        sessions.print_output()
        print ''

    def iscsi_scan(self):
        logging.info('Refreshing iSCSI connections')
        command = ExternalCommand('iscsiadm -m node -U all')
        command.execute()
        command = ExternalCommand('iscsiadm -m node -L all')
        command.execute()

