#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import time
import os
import logging
from shutil import copyfile

import definitions
from file import File
from hostattachment.exceptions import HostAttachmentError
from hostattachment.platform.classes import get_os_string

class UdevRules(object):
    def __init__(self, backup_path):
        self.os_string = get_os_string()
        self.rules_source = definitions.UDEV_RULES_SOURCE
        self.udev_rules = []
        self.udev_rules.append('40-multipath.rules')
        self.udev_rules.append('45-ibm-xiv.rules')
        self.backup_path = backup_path

    def is_configured(self):
        if self.dest_rules_identical_to_source_rules_dst_files() == False:
            return False
        else:
            return True

    def get_src_file(self, dir, filename):
        """Tries all optional filenames in an array and returns the first
        match. In this case, try os-specific first and then generic version"""
        options = []
        options.append('%s/%s.%s' % (dir, filename, self.os_string))
        options.append('%s/%s' % (dir, filename))

        for option in options:
            if (os.path.exists(option)):
                return option

        raise HostAttachmentError("Cannot find any of the following files:"+\
            "\n%s" % (options) )

    def dest_rules_identical_to_source_rules_dst_files(self):
        for filename in self.udev_rules:
            src = self.get_src_file(self.rules_source, filename)
            dst = File('%s/%s' % ('/etc/udev/rules.d', filename))
            try:
                diff_result = dst.identical_to_file(src)
            except IOError:
                return False
            if not diff_result:
                return False

        return True

    def backup(self, src):
        backup_file = "%s%s%s.%s" % (self.backup_path, os.path.sep,
            os.path.basename(src), time.strftime("%Y%m%d%H%m%S"))

        if (os.path.exists(src)):
            copyfile(src, backup_file)

    def configure(self):
        for filename in self.udev_rules:
            source_filename = self.get_src_file(self.rules_source, filename)
            source_file = File(source_filename)
            dest_filename = '%s/%s' % ('/etc/udev/rules.d', filename)
            self.backup(dest_filename)
            try:
                copy_result = source_file.copy_to(dest_filename)
                logging.info('udev rule %s configured successfully' % filename)
            except IOError:
                raise HostAttachmentError('failed to read udev rule file %s' %\
                    (filename) )

            if not copy_result:
                raise HostAttachmentError('failed to write udev rule file '+\
                    '%s' % (dest_filename) )

